//-----------------------------------------------------------------------------
// flash.h
//-----------------------------------------------------------------------------
// Copyright 2004 Silicon Laboratories, Inc.
//
// This program contains several useful utilities for writing and updating
// FLASH memory.
//
// AUTH: BW & GP
// DATE: 21 JUL 04
//
// Target: C8051F32x
// Tool chain: KEIL C51 7.06
//
// Release 1.0
//
#ifndef F320_FLASH_H_
#define F320_FLASH_H_

//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Structures, Unions, Enumerations, and Type Definitions
//-----------------------------------------------------------------------------

typedef unsigned long ULONG;
typedef unsigned int UINT;
typedef unsigned char UCHAR;

//-----------------------------------------------------------------------------
// Global Constants
//-----------------------------------------------------------------------------

#ifndef FLASH_PAGESIZE
#define FLASH_PAGESIZE 512
#endif

#ifndef FLASH_TEMP
#define FLASH_TEMP 0x03a00L
#endif

#ifndef FLASH_LAST
#define FLASH_LAST 0x03c00L
#endif

typedef UINT FLADDR;

//-----------------------------------------------------------------------------
// Exported Function Prototypes
//-----------------------------------------------------------------------------

// FLASH read/write/erase routines
extern void flash_WriteByte (FLADDR addr, char byte);
extern unsigned char flash_ReadByte (FLADDR addr);
extern void flash_ErasePage (FLADDR addr);

// FLASH read/write/erase routines
extern void flash_WriteBuf (FLADDR dest, char *src, unsigned numbytes);
extern char * flash_ReadBuf (char *dest, FLADDR src, unsigned numbytes);
extern void flash_Clear (FLADDR addr, unsigned numbytes);

// FLASH update/copy routines
extern void flash_Update (FLADDR dest, char *src, unsigned numbytes);   // copy with destination preservation
extern void flash_Copy (FLADDR dest, FLADDR src, unsigned numbytes);    // low-level FLASH/FLASH byte copy

// FLASH test routines
extern void flash_Fill (FLADDR addr, ULONG length, UCHAR fill);
#endif // F320_FLASH_H_
